@@ -8,23 +8,16 @@
 import os
 import sys
 
-import django
-from sphinxawesome_theme.postprocess import Icons
-
-sys.path.insert(0, os.path.abspath("../.."))
-os.environ["DJANGO_SETTINGS_MODULE"] = "terminusgps.django.settings"
-django.setup()
-
+sys.path.insert(0, os.path.abspath("../../"))
 project = "python-terminusgps"
 copyright = "2025, Terminus GPS, LLC"
 author = "Terminus GPS, LLC"
-release = "43.0.1"
+release = "43.1.0"
 
 # -- General configuration ---------------------------------------------------
 # https://www.sphinx-doc.org/en/master/usage/configuration.html#general-configuration
 
 extensions = [
-    "autoclasstoc",
     "sphinx.ext.autodoc",
     "sphinx.ext.autosummary",
     "sphinx.ext.intersphinx",
@@ -32,7 +25,7 @@ extensions = [
 ]
 
 intersphinx_mapping = {
-    "python": ("https://docs.python.org/3", None),
+    "python": ("https://docs.python.org/3/", None),
     "django": (
         "http://docs.djangoproject.com/en/stable/",
         "http://docs.djangoproject.com/en/stable/_objects/",
@@ -47,7 +40,6 @@ exclude_patterns = []
 # https://www.sphinx-doc.org/en/master/usage/configuration.html#options-for-html-output
 
 html_theme = "sphinxawesome_theme"
-html_permalinks_icon = Icons.permalinks_icon
 pygments_style = "sas"
 pygments_style_dark = "lightbulb"
 html_static_path = ["_static"]
